#ifdef GL_ES
precision highp float;
#endif
varying highp vec2 textureCoordinate;
uniform sampler2D uvTexture;
const mat3 yuv2rgb = mat3( 1, 0, 1.402, 1, -0.344, -0.714, 1, 1.772, 0 );
uniform sampler2D inputImageTexture;
uniform highp vec2 center;
uniform highp float radius;
uniform highp float aspectRatio;
uniform highp float refractiveIndex;
uniform mediump float topMargin;
uniform mediump float refractPosition;
void main()
{
highp vec2 textureCoordinateToUse = vec2(textureCoordinate.x, (textureCoordinate.y * aspectRatio + center.y - center.y * aspectRatio));\
highp float distanceFromCenter = distance(center, textureCoordinateToUse);
lowp float checkForPresenceWithinSphere = smoothstep(radius, radius - 0.02, distanceFromCenter);
distanceFromCenter = distanceFromCenter / radius;
highp float normalizedDepth = radius * sqrt(1.0 - distanceFromCenter * distanceFromCenter);
highp vec3 sphereNormal = normalize(vec3(textureCoordinateToUse - center, normalizedDepth));
highp vec3 refractedVector = 2.0 * refract(vec3(0.0, 0.0, refractPosition), sphereNormal, refractiveIndex);
refractedVector.xy = -refractedVector.xy;
refractedVector.x = refractedVector.x * 0.75;
vec2 uv = texture2D( uvTexture, textureCoordinate ).ar;
vec3 yuv = vec3( texture2D( inputImageTexture,   (refractedVector.xy + 1.0) * 0.5 ).r, uv - 0.5 );
vec3 finalSphereColor = yuv * yuv2rgb;
gl_FragColor = vec4(finalSphereColor * checkForPresenceWithinSphere, 1.0);
}